<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Здогад</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Знайти</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Звичайна</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Велика</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Невдача</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Успішно</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Гру завершено</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 з %n очка</numerusform>
            <numerusform>%1 з %n очок</numerusform>
            <numerusform>%1 з %n очок</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 з %n очка</numerusform>
            <numerusform>3 з %n очок</numerusform>
            <numerusform>3 із %n очок</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n очко</numerusform>
            <numerusform>%n очка</numerusform>
            <numerusform>%n очок</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Максимальна оцінка вирахувана з наступних тридцяти слів:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n здогадка</numerusform>
            <numerusform>%n здогадки</numerusform>
            <numerusform>%n здогадок</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n хід</numerusform>
            <numerusform>%n ходи</numerusform>
            <numerusform>%n ходів</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Класика</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Поповнення</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Витривалість</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Три удари</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Квота 30</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Дисципліна</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Підрахунок ведеться від 30 секунд і збільшується за правильні здогадки.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Підрахунок ведеться від 3 хвилин.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Підрахунок ведеться від 30 секунд і поповнюється за правильні здогадки.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Підрахунок ведеться від 45 секунд і призупиняється за правильні здогадки.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Гра завершується після 3 неправильних здогадок.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Гра завершується після 30 здогадок.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Підрахунок ведеться від 30 секунд і зростає або зменшується за правильні або неправильні здогадки.</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation>Необмежений</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation>Гра закінчується, коли знайдено всі слова.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Не вдалось прочитати розкладку з файла.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Не вдалось прочитати список слів з файла.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Параметри мови</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Власна</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Вибрати...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Заувага:&lt;/b&gt; Ці параметри набудуть сили після запуску нової гри.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Мова:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Розкладка:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Список слів:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Словник:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Вибрати файл розкладки</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Вибрати файл списку слів</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Вибрати мову програми:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примітка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Перезапустіть програму, щоб зміна мови вступила в силу.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Нова гра</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Кількість слів:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Мінімальна довжина слова:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Випадкові</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Найвищий рахунок</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Ім&apos;я</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Оцінка</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>№%1</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Ранг</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation>Максимум</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Розмір</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Вітаємо!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Ви перемогли ваш найкращий результат!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Молодець!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>У вас новий високий бал!</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Пауза&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Клацніть, щоб відновити гру.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Натисніть, щоб розпочати нову гру.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Зачекайте&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Генерування нової розкладки...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Гра</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Вибрати...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Завершити</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Подробиці</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Найвищі рахунки</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Вийти</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Параметри</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Показати &amp;найбільший рахунок</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Ніколи</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Кінець гри</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Завжди</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Показувати невдалі &amp;слова</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>Мова роз&amp;кладки...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Мова про&amp;грами...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Довідка</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Керування</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Про &amp;програму</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Про &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Про</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Варіант гри для одного гравця &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Розповсюджується за умовами ліцензії &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Імпорт гри</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Не вдалось запустити запитану гру.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Помилка</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Експорт гри</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Запитання</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Завершити поточну гру?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Розмір дошки:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Звичайна</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Велика</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Щільність слів:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Довжина слова:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 або більше букв</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Тип гри:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Опис:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Керування</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Гра мишею:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Вибрати слово:&lt;/b&gt; Клацання на буквах слова.&lt;br&gt;&lt;b&gt;Зробити припущення:&lt;/b&gt; Клацнути на останній вибраній букві.&lt;br&gt;&lt;b&gt;Викреслити букви:&lt;/b&gt; Клацнути на раніше вибраній букві.&lt;br&gt;&lt;b&gt;Очистити слово:&lt;/b&gt; Двічі клацнути на першій букві.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Гра з клавіатури:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Вибрати слово:&lt;/b&gt; Ввести букви слова.&lt;br&gt;&lt;b&gt;Зробити припущення:&lt;/b&gt; Натиснути клавішу «Enter».&lt;br&gt;&lt;b&gt;Очистити слово:&lt;/b&gt; Натиснути «Ctrl+Backspace».&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Знайдено:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n очко</numerusform>
            <numerusform>%n очка</numerusform>
            <numerusform>%n очок</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Гра в пошук слова</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Ігровий файл для відтворення.</translation>
    </message>
</context>
</TS>
